.. spyctl documentation master file, created by
   sphinx-quickstart on Mon Jan  9 12:33:46 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Spyctl
==========================

Release v\ |version|. (:ref:`Installation <install>`)

.. image:: https://img.shields.io/github/downloads/spyderbat/spyctl/total
   :alt: GitHub all releases

.. image:: https://img.shields.io/github/issues/spyderbat/spyctl
   :target: https://github.com/spyderbat/spyctl/issues
   :alt: GitHub issues

.. image:: https://img.shields.io/github/issues-closed/spyderbat/spyctl
   :target: https://github.com/spyderbat/spyctl/issues?q=is%3Aissue+is%3Aclosed
   :alt: GitHub closed issues

.. image:: https://img.shields.io/github/license/spyderbat/spyctl
   :alt: GitHub

.. image:: https://img.shields.io/github/stars/spyderbat/spyctl?style=social
   :alt: GitHub Repo stars


**Spyctl** is a tool for viewing and managing Spyderbat Resources.


Understanding Spyctl
----------------------

Learn about Spyctl and its fundamental concepts.

.. toctree::
   :maxdepth: 1

   getting_started/getting_started
   tutorials/tutorials

Reference
---------

.. toctree::
   :maxdepth: 1

   user/configuration
   user/resources
   user/spyderbat_concepts
   user/commands

Indices and Tables
-------------------

* :ref:`search`
